@@ -329,8 +329,8 @@ class LogstashHandler(logging.Handler):
                     "exc_text", "stack_info", "lineno", "funcName", "created", "msecs", "relativeCreated", "thread",
                     "threadName", "processName", "process", "message",
                     "logger_data", "extra_data", "short_message", "app_name", "host_name"]
-    LOGGER_DATA = ["name", "levelname", "levelno", "pathname", "filename", "module", "exc_info",
-                   "exc_text", "stack_info", "lineno", "funcName", "created", "msecs", "relativeCreated", "thread",
+    LOGGER_DATA = ["name", "levelname", "levelno", "pathname", "filename", "module",
+                   "exc_text", "lineno", "funcName", "created", "msecs", "relativeCreated", "thread",
                    "threadName", "processName", "process"]
 
     def __init__(self, log_server: str, app_name: str = None, host_name: str = None, extra_data: dict = None):
